### Name: riv
### Title: Robust instrumental variables estimator
### Aliases: riv
### Keywords: robust multivariate

### ** Examples

## load data earthquake: the first column contains the response Y, the second the endogenous variable X 
## and the third column is the instrument W.
data(earthquake) 
riv.eq <- riv(earthquake[,1],FALSE,earthquake[,2],earthquake[,3]) 

## plot of the riv estimates and the outlying observations are identified by filled points
plot(earthquake[,2],earthquake[,1],xlab="X",ylab="Y",cex=1.5)
abline(riv.eq$Summary.Table[,1])
case <- 1:62
text(earthquake[riv.eq$MD>sqrt(qchisq(0.95, 3)),2],earthquake[riv.eq$MD>sqrt(qchisq(0.95, 3)),1],
case[riv.eq$MD>sqrt(qchisq(0.95, 3))],pos=c(1,4,2,2,3,2))
points(earthquake[riv.eq$MD>sqrt(qchisq(0.95, 3)),2],earthquake[riv.eq$MD>sqrt(qchisq(0.95, 3)),1],cex=1.5,pch=19)

## Mahalanobis distances of the S-estimator of multivariate location and covariance (slc)

case <- 1:62
plot(riv.eq$MD,xlab="Case number",ylab="Mahalanobis Distance",cex = 1.5)
abline(h=sqrt(qchisq(0.95, 3)))
text(case[riv.eq$MD>sqrt(qchisq(0.95, 3))],riv.eq$MD[riv.eq$MD>sqrt(qchisq(0.95, 3))],
case[riv.eq$MD>sqrt(qchisq(0.95, 3))],pos=c(3,3,3,3,2,3))

## Weights associated to each observation 

plot(riv.eq$weight,xlab="Case number",ylab="Weight",cex=1.5)
abline(h=0)
text(case[riv.eq$MD>sqrt(qchisq(0.95, 3))],riv.eq$weight[riv.eq$MD>sqrt(qchisq(0.95, 3))],
case[riv.eq$MD>sqrt(qchisq(0.95, 3))],pos=c(3,3,3,2,3,3),col=c("black","black","red","black","red","black"))
points(case[riv.eq$weight==0],riv.eq$weight[riv.eq$weight==0],col="red",cex=1.5,pch=19)

## load data mortality

data(mortality) 
Y <- as.matrix(mortality[,1])            ## M070
Xex <- as.matrix(mortality[,c(2,3,5,6)]) ## MAGE,CI68,DENS,NONW 
Xend <- as.matrix(mortality[,4])         ## MDOC  
colnames(Xend) <- colnames(mortality)[4] 
W <- as.matrix(mortality[,7:8])          ## EDUC,IN69

## Classical instrumental variables estimator
riv(Y,Xex,Xend,W,method="classical")     



